@@ -2,7 +2,8 @@
 
 from __future__ import annotations
 
-from typing import Any, Callable
+from collections.abc import Callable
+from typing import Any
 
 # A converter type
 MapConverterType = Callable[..., Any] | list[Callable[..., Any]]
@@ -11,4 +12,6 @@ MapConverterType = Callable[..., Any] | list[Callable[..., Any]]
 MapValueType = str | tuple[str] | tuple[str, MapConverterType]
 
 # A map replace type - this value should be found, renamed and converted
-MapReplaceType = str | tuple[str] | tuple[str, str] | tuple[str, str, MapConverterType]
+MapReplaceType = (
+    str | tuple[str] | tuple[str, str] | tuple[str, str, MapConverterType]
+)
