@@ -5,8 +5,8 @@ from __future__ import annotations
 from typing import Any
 
 
-def read(content: str) -> dict[str, Any]:  # pylint: disable=unused-argument
-    """Read state data"""
+def read(content: str) -> dict[str, Any]:
+    """Read state data."""
 
     # Read the json content
     state: dict[str, Any] = {}
