@@ -1,17 +1,19 @@
-"""Converters module
+"""Converters module.
 
 This module has methods to convert data between different formats
 without complicated logic. In case data cannot be converted,
 `None` is returned and no exception is raised.
 
 If data conversion requires complicated logic,
-it should be in the Readers module"""
+it should be in the Readers module
+"""
 
 from __future__ import annotations
 
-from datetime import datetime, timedelta, timezone
+from collections.abc import Callable, Iterable
+from datetime import UTC, datetime, timedelta
 from enum import Enum
-from typing import Any, Callable, Iterable, Optional, Type, TypeVar, cast
+from typing import Any, TypeVar, cast
 
 from asusrouter.tools.cleaners import clean_content
 
@@ -24,9 +26,11 @@ _E = TypeVar("_E", bound=Enum)
 
 
 def clean_input(func: Callable[..., Any]) -> Callable[..., Any]:
-    """Decorator to clean input data."""
+    """Clean input data."""
+
+    def wrapper(content: Any, *args: Any, **kwargs: Any) -> Any:
+        """Return a clean input data before passing it to the function."""
 
-    def wrapper(content: Any, *args, **kwargs) -> Any:
         if isinstance(content, str):
             return func(clean_string(content), *args, **kwargs)
         return func(content, *args, **kwargs)
@@ -34,7 +38,7 @@ def clean_input(func: Callable[..., Any]) -> Callable[..., Any]:
     return wrapper
 
 
-def clean_string(content: Optional[str]) -> Optional[str]:
+def clean_string(content: str | None) -> str | None:
     """Get a clean string or return None if it is empty."""
 
     # Not a string
@@ -50,11 +54,11 @@ def clean_string(content: Optional[str]) -> Optional[str]:
 
 
 def flatten_dict(
-    d: Optional[dict[Any, Any]],
+    d: dict[Any, Any] | None,
     parent_key: str = "",
     sep: str = "_",
-    exclude: Optional[str | Iterable[str]] = None,
-) -> Optional[dict[str, Any]]:
+    exclude: str | Iterable[str] | None = None,
+) -> dict[str, Any] | None:
     """Flatten a nested dictionary."""
 
     if d is None:
@@ -87,7 +91,7 @@ def flatten_dict(
 
 def get_arguments(
     args: str | tuple[str, ...], **kwargs: Any
-) -> Any | tuple[Optional[Any], ...]:
+) -> Any | tuple[Any | None, ...]:
     """Get the arguments from kwargs."""
 
     # Make sure args is a tuple
@@ -96,7 +100,7 @@ def get_arguments(
 
     arguments = kwargs.get("arguments", {})
 
-    found_args: list[Optional[Any]] = []
+    found_args: list[Any | None] = []
 
     for arg in args:
         # Skip if not a string
@@ -113,9 +117,9 @@ def get_arguments(
 
 
 def get_enum_key_by_value(
-    enum: Type[_E], value: Any, default: Optional[_E] = None
+    enum: type[_E], value: Any, default: _E | None = None
 ) -> _E:
-    """Get the enum key by value"""
+    """Get the enum key by value."""
 
     if issubclass(enum, Enum):
         for enum_value in enum:
@@ -128,9 +132,7 @@ def get_enum_key_by_value(
     raise ValueError(f"Invalid value: {value}")
 
 
-def handle_none_content(
-    content: Optional[_T], default: Optional[_T]
-) -> Optional[_T]:
+def handle_none_content(content: _T | None, default: _T | None) -> _T | None:
     """Return the default value if content is None, else return the content."""
 
     if content is None:
@@ -156,7 +158,7 @@ def int_as_bits(value: int) -> list[bool]:
 
 
 def int_as_capabilities(
-    value: int, capabilities: Type[Enum]
+    value: int, capabilities: type[Enum]
 ) -> dict[Enum, bool]:
     """Convert an integer to a dict of capabilities."""
 
@@ -184,13 +186,13 @@ def int_as_capabilities(
     return result
 
 
-def is_enum(v) -> bool:
+def is_enum(v: Any) -> bool:
     """Check if the value is an enum."""
 
     return isinstance(v, type) and issubclass(v, Enum)
 
 
-def list_from_dict(raw: Optional[dict[Any, Any] | list[Any]]) -> list[str]:
+def list_from_dict(raw: dict[Any, Any] | list[Any] | None) -> list[str]:
     """Return dictionary keys as list."""
 
     if isinstance(raw, list):
@@ -203,14 +205,14 @@ def list_from_dict(raw: Optional[dict[Any, Any] | list[Any]]) -> list[str]:
 
 
 def nvram_get(
-    content: Optional[list[str] | str],
-) -> Optional[list[tuple[str, ...]]]:
+    content: list[str] | str | None,
+) -> list[tuple[str, ...]] | None:
     """Convert values to NVRAM request."""
 
     if not content:
         return None
 
-    if not isinstance(content, (list, str)):
+    if not isinstance(content, list | str):
         content = str(content)
 
     if isinstance(content, str):
@@ -220,7 +222,7 @@ def nvram_get(
 
 
 def run_method(
-    value: Any, method: Optional[Callable[..., Any] | list[Callable[..., Any]]]
+    value: Any, method: Callable[..., Any] | list[Callable[..., Any]] | None
 ) -> Any:
     """Run a method or a list of methods on a value and return the result."""
 
@@ -243,7 +245,7 @@ def run_method(
 
 
 @clean_input
-def safe_bool(content: Optional[str | int | float | bool]) -> Optional[bool]:
+def safe_bool(content: str | float | bool | None) -> bool | None:
     """Read the content as boolean or return None."""
 
     if content is None:
@@ -251,7 +253,7 @@ def safe_bool(content: Optional[str | int | float | bool]) -> Optional[bool]:
 
     if isinstance(content, bool):
         return content
-    if isinstance(content, (int, float)):
+    if isinstance(content, int | float):
         return content != 0
     if isinstance(content, str):
         content = content.lower()
@@ -265,12 +267,14 @@ def safe_bool(content: Optional[str | int | float | bool]) -> Optional[bool]:
 
 def safe_convert(
     convert_func: Callable[[str | int | float], _T],
-    content: Optional[str | int | float],
-    default: Optional[_T] = None,
-    fallback_func: Optional[Callable[[Any], _T]] = None,
-) -> Optional[_T]:
-    """Try to convert the content using the conversion function,
-    return the default value if it fails."""
+    content: str | float | None,
+    default: _T | None = None,
+    fallback_func: Callable[[Any], _T] | None = None,
+) -> _T | None:
+    """Try to convert the content using the conversion function.
+
+    Return the default value if it fails.
+    """
 
     if content is None:
         return default
@@ -286,7 +290,7 @@ def safe_convert(
 
 
 @clean_input
-def safe_datetime(content: Optional[str]) -> Optional[datetime]:
+def safe_datetime(content: str | None) -> datetime | None:
     """Read the content as datetime or return None."""
 
     if not content:
@@ -302,12 +306,12 @@ def safe_datetime(content: Optional[str]) -> Optional[datetime]:
 
 
 def safe_enum(
-    enum: Type[_E],
+    enum: type[_E],
     value: Any,
-    default_value: Optional[Any] = None,
-    default: Optional[_E] = None,
-) -> Optional[_E]:
-    """Get the enum key by value"""
+    default_value: Any | None = None,
+    default: _E | None = None,
+) -> _E | None:
+    """Get the enum key by value."""
 
     # Fast return
     # Return the default enum member
@@ -333,37 +337,37 @@ def safe_enum(
 
 
 @clean_input
-def safe_exists(content: Optional[str]) -> bool:
+def safe_exists(content: str | None) -> bool:
     """Read the content as boolean or return None."""
 
-    if content is None:
-        return False
-
-    return True
+    return content is not None
 
 
 @clean_input
 def safe_float(
-    content: Optional[str | int | float], default: Optional[float] = None
-) -> Optional[float]:
+    content: str | float | None, default: float | None = None
+) -> float | None:
     """Read the content as float or return None."""
 
     content = cast(
-        Optional[str | int | float], handle_none_content(content, default)
+        str | int | float | None, handle_none_content(content, default)
     )
     return safe_convert(float, content, default)
 
 
 @clean_input
 def safe_int(
-    content: Optional[str | int | float],
-    default: Optional[int] = None,
+    content: str | float | None,
+    default: int | None = None,
     base: int = 10,
-) -> Optional[int]:
-    """Read the content as int or return the default value (None if not specified)."""
+) -> int | None:
+    """Read the content as int or return the default value.
+
+    (None if not specified).
+    """
 
     content = cast(
-        Optional[str | int | float], handle_none_content(content, default)
+        str | int | float | None, handle_none_content(content, default)
     )
     if isinstance(content, str):
         return safe_convert(
@@ -389,7 +393,7 @@ def safe_list(content: Any) -> list[Any]:
     return [content]
 
 
-def safe_list_csv(content: Optional[str]) -> list[str]:
+def safe_list_csv(content: str | None) -> list[str]:
     """Read the list as comma separated values."""
 
     return safe_list_from_string(content, ",")
@@ -397,7 +401,7 @@ def safe_list_csv(content: Optional[str]) -> list[str]:
 
 @clean_input
 def safe_list_from_string(
-    content: Optional[str], delimiter: str = " "
+    content: str | None, delimiter: str = " "
 ) -> list[str]:
     """Read the content as list or return empty list."""
 
@@ -415,13 +419,14 @@ def safe_return(content: Any) -> Any:
 
 
 def safe_speed(
-    current: (int | float),
-    previous: (int | float),
-    time_delta: (int | float) | None = None,
+    current: (float),
+    previous: (float),
+    time_delta: float | None = None,
 ) -> float:
     """Calculate speed.
 
-    Allows calculation only of positive speed, otherwise returns 0.0."""
+    Allows calculation only of positive speed, otherwise returns 0.0.
+    """
 
     if time_delta is None or time_delta == 0.0:
         return 0.0
@@ -434,15 +439,18 @@ def safe_speed(
 def safe_time_from_delta(content: str) -> datetime:
     """Transform time delta to the date in the past."""
 
-    return datetime.now(timezone.utc).replace(
-        microsecond=0, tzinfo=timezone.utc
+    return datetime.now(UTC).replace(
+        microsecond=0, tzinfo=UTC
     ) - safe_timedelta_long(content)
 
 
 @clean_input
-def safe_timedelta_long(content: Optional[str]) -> timedelta:
-    """Transform connection timedelta of the device to a proper
-    datetime object when the device was connected"""
+def safe_timedelta_long(content: str | None) -> timedelta:
+    """Transform connection timedelta.
+
+    Transform timedelta of the device to a proper datetime object
+    when the device was connected.
+    """
 
     if not content:
         return timedelta()
@@ -457,18 +465,17 @@ def safe_timedelta_long(content: Optional[str]) -> timedelta:
 
 
 def safe_unpack_key(
-    content: tuple[
-        str, Optional[Callable[..., Any]] | list[Callable[..., Any]]
-    ]
+    content: tuple[str, Callable[..., Any] | None | list[Callable[..., Any]]]
     | str
     | tuple[str],
-) -> tuple[str, Optional[Callable[..., Any] | list[Callable[..., Any]]]]:
+) -> tuple[str, Callable[..., Any] | list[Callable[..., Any]] | None]:
     """
     Unpacks a tuple containing a key and a method.
 
     The input can be a tuple of a string and a method, a single string,
     or a single-item tuple with a string.
-    If the input is a string or a single-item tuple, the returned method is None.
+    If the input is a string or a single-item tuple, the returned method
+    is None.
     If the input is a tuple of a string and a method, both are returned as is.
 
     Args:
@@ -486,7 +493,7 @@ def safe_unpack_key(
             content = cast(
                 tuple[
                     str,
-                    Optional[Callable[..., Any]] | list[Callable[..., Any]],
+                    Callable[..., Any] | None | list[Callable[..., Any]],
                 ],
                 content,
             )
@@ -505,21 +512,20 @@ def safe_unpack_key(
 
 def safe_unpack_keys(
     content: tuple[
-        str, str, Optional[Callable[..., Any]] | list[Callable[..., Any]]
+        str, str, Callable[..., Any] | None | list[Callable[..., Any]]
     ]
     | tuple[str, str]
     | str,
 ) -> tuple[Any, ...]:
-    """Method to unpack key/key_to_use/method tuple
-    even if some values are missing."""
+    """Unpack key/key_to_use/method tuple even if some values are missing."""
 
     if isinstance(content, tuple):
         # All 3 values are present
-        if len(content) == 3:
+        if len(content) == 3:  # noqa: PLR2004
             return content
 
         # No method selected
-        if len(content) == 2:
+        if len(content) == 2:  # noqa: PLR2004
             return content + (None,)
 
     # No method and key_to_use selected
@@ -528,10 +534,11 @@ def safe_unpack_keys(
     return new_content + (None,)
 
 
-def safe_usage(used: int | float, total: int | float) -> float:
+def safe_usage(used: float, total: float) -> float:
     """Calculate usage in percents.
 
-    Allows calculation only of positive usage, otherwise returns 0.0."""
+    Allows calculation only of positive usage, otherwise returns 0.0.
+    """
 
     if total == 0:
         return 0.0
@@ -546,14 +553,15 @@ def safe_usage(used: int | float, total: int | float) -> float:
 
 
 def safe_usage_historic(
-    used: int | float,
-    total: int | float,
-    prev_used: int | float,
-    prev_total: int | float,
+    used: float,
+    total: float,
+    prev_used: float,
+    prev_total: float,
 ) -> float:
-    """Calculate usage in percents for difference between current and previous values
+    """Calculate usage in percents for difference between values.
 
-    This method is just an interface to calculate usage using `usage` method"""
+    This method is just an interface to calculate usage using `usage` method
+    """
 
     used_diff = used - prev_used
     total_diff = total - prev_total
@@ -565,22 +573,22 @@ def safe_usage_historic(
     return safe_usage(used_diff, total_diff)
 
 
-def safe_timestamp_to_utc(value: Optional[int]) -> Optional[datetime]:
+def safe_timestamp_to_utc(value: int | None) -> datetime | None:
     """Convert timestamp to UTC datetime."""
 
     if value is None:
         return None
 
     try:
-        return datetime.fromtimestamp(value, timezone.utc)
+        return datetime.fromtimestamp(value, UTC)
     except (ValueError, TypeError, OSError):
         try:
-            return datetime.fromtimestamp(value / 1000, timezone.utc)
+            return datetime.fromtimestamp(value / 1000, UTC)
         except (ValueError, TypeError, OSError):
             return None
 
 
-def safe_utc_to_timestamp(value: Optional[datetime]) -> Optional[float]:
+def safe_utc_to_timestamp(value: datetime | None) -> float | None:
     """Convert UTC datetime to timestamp."""
 
     if value is None or not isinstance(value, datetime):
@@ -589,7 +597,7 @@ def safe_utc_to_timestamp(value: Optional[datetime]) -> Optional[float]:
     return value.timestamp()
 
 
-def safe_utc_to_timestamp_milli(value: Optional[datetime]) -> Optional[int]:
+def safe_utc_to_timestamp_milli(value: datetime | None) -> int | None:
     """Convert UTC datetime to timestamp in milliseconds."""
 
     _timestamp = safe_utc_to_timestamp(value)
@@ -603,7 +611,7 @@ def safe_utc_to_timestamp_milli(value: Optional[datetime]) -> Optional[int]:
 def scale_value_int(
     value: int,
     scale: int,
-    scale_from: Optional[int] = None,
+    scale_from: int | None = None,
 ) -> int:
     """Scale the value from the custom scale."""
 
